merlin.utils package
====================

.. automodule:: merlin.utils
   :members:
   :undoc-members:
   :show-inheritance:

Modules
-------

.. toctree::
   :maxdepth: 4

   merlin.utils.grouping

